import * as React from 'react';
import { __ } from '@wordpress/i18n';

import { BlockEditProps } from '@wordpress/blocks';
import { Placeholder, ExternalLink } from '@wordpress/components';

import CogIcon from '@/assets/cogicon';
import SelectDialog from '@/components/select-dialog';
import PreviewForm from '@/components/preview-form';
import { BlockAttributes, EmbedMode } from '@/types';

const Edit: React.FC<BlockEditProps<BlockAttributes>> = ( { attributes, setAttributes, className } ) => {
	const handleForm = ( form: { [key: string]: any } ) => {
		setAttributes( {
			formId: form.formId,
			seamlessEmbedCode: form.embedCodes.Seamless,
			iframeEmbedCode: form.embedCodes.IFrame,
			ampEmbedCode: form.embedCodes.Amp,
			embedMode: EmbedMode.Seamless,
		} );
	};

	if ( ! attributes.formId ) {
		return (
			<Placeholder
				icon={ CogIcon }
				label="Cognito Forms"
				className={ className }
				instructions={ __(
					'Click the button below to choose a form to embed.'
				) }
			>
				<SelectDialog onSelectForm={ handleForm }></SelectDialog>
				<br />
				<div className="components-placeholder__learn-more">
					<ExternalLink
						href={ __(
							'https://wordpress.org/support/article/embeds/'
						) }
					>
						{ __( 'Learn more about embeds' ) }
					</ExternalLink>
				</div>
			</Placeholder>
		);
	}

	return (
		<PreviewForm
			formId={ attributes.formId } // TODO: this should actually be the form GUID
			embedCode={ attributes.iframeEmbedCode }
		/>
	);
};

export default Edit;
